@@ -20,6 +20,10 @@
 
 *******************************************************************************/
 
+/* Include system headers before local headers - the local headers
+ * redefine __inline, which can mess up definitions in libc headers if
+ * they happen to use __inline. */
+#include <string.h>
 #include "basic_op.h"
 #include "oper_32b.h"
 #include "adj_thr_data.h"
@@ -1129,7 +1133,7 @@ void AdjustThresholds(ADJ_THR_STATE   *adjThrState,
 					  const Word16     nChannels,
                       const Word16     maxBitFac)
 {
-  PE_DATA peData = { 0 };
+  PE_DATA peData;
   Word16 noRedPe, grantedPe, grantedPeCorr;
   Word16 curWindowSequence;
   Word16 bitFactor;
@@ -1138,6 +1142,7 @@ void AdjustThresholds(ADJ_THR_STATE   *adjThrState,
   Word16 maxBitresBits = elBits->maxBits;
   Word16 sideInfoBits = (qcOE->staticBitsUsed + qcOE->ancBitsUsed);
   Word16 ch;
+  memset(&peData, 0, sizeof(peData));
 
   prepareSfbPe(&peData, psyOutChannel, logSfbEnergy, sfbNRelevantLines, nChannels, AdjThrStateElement->peOffset);
 
